======
Naming
======

Kopf is an abbreviation either for
**K**\ubernetes **O**\perator **P**\ythonic **F**\ramework, or for
**K**\ubernetes **OP**\erator **F**\ramework --- whatever you like more.

"Kopf" also means "head" in German.

It is capitalised in all natural language texts:

    *I like using Kopf to manage my domain in Kubernetes.*

It is lower-cased in all system and code references::

    pip install kopf
    import kopf
